@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package IPv6::Address;
-$IPv6::Address::VERSION = '0.201';
+$IPv6::Address::VERSION = '0.203';
 
 =head1 NAME
 
@@ -10,11 +10,12 @@ IPv6::Address - IPv6 Address Manipulation Library
 
 =head1 VERSION
 
-version 0.201
+version 0.203
 
 =for html
 <a href="https://travis-ci.org/aduitsis/IPv6-Address"><img src="https://travis-ci.org/aduitsis/IPv6-Address.svg?branch=master"></a>
-<a href='https://coveralls.io/r/aduitsis/IPv6-Address?branch=master'><img src='https://coveralls.io/repos/aduitsis/IPv6-Address/badge.svg?branch=master' alt='Coverage Status' /></a> 
+<a href='https://coveralls.io/r/aduitsis/IPv6-Address?branch=master'><img src='https://coveralls.io/repos/aduitsis/IPv6-Address/badge.svg?branch=master' alt='Coverage Status' /></a>
+
 
 =head1 SYNOPSIS
 
@@ -33,8 +34,8 @@ version 0.201
  
  $ipv6->addr_string; # Returns '2001:648:2000::'
  
- $ipv6->split(4); # Split the prefix into 2^4 smaller prefixes. Returns a list.
- 
+ $ipv6->split(4); # Split the prefix into 2^4 smaller prefixes. Returns a list.  
+
  $ipv6->apply_mask; # Apply the mask to the address. All bits beyond the mask length become 0.
 
  $ipv6->first_address;
@@ -267,10 +268,10 @@ Returns the address part of the IPv6::Address. Using the option ipv4=>1 like
 
  $a->addr_string(ipv4=>1) 
 
-will make the last 32-bits appear as an IPv4 address. Also, using nocompress=1
+will make the last 32-bits appear as an IPv4 address. Also, using nocompress=>1
 like 
 
- $a->addr_string(nocompress=1) 
+ $a->addr_string( nocompress => 1 ) 
 
 will prevent the string from containing a '::' part. So it will be 8 parts
 separated by ':' colons. 
@@ -634,7 +635,7 @@ sub radius_string {
 }
 
 package IPv4Subnet;
-$IPv4Subnet::VERSION = '0.201';
+$IPv4Subnet::VERSION = '0.203';
 use Socket;
 use strict;
 use Carp;
@@ -645,10 +646,18 @@ use Data::Dumper;
 sub new {
 	defined ( my $class = shift ) or die "missing class";
 	defined ( my $str = shift ) or die "missing string";
-	my ( $ip , $length_n ) = ( $str =~ /^(\d+\.\d+\.\d+\.\d+)\/(\d+)$/ ) or croak 'Cannot parse $str';
+	my ( $ip , $length_n ) = ( $str =~ /^(\d+\.\d+\.\d+\.\d+)\/(\d+)$/ ) or croak "Cannot parse $str";
 	bless { ip_n => my_aton($ip) , length_n => $length_n } , $class	;
 }
 
+sub new_from_start_stop { 
+	$_[0]->new( $_[1].'/'.(32 - log(  ( my_aton($_[1]) ^ my_aton($_[2]) )  + 1)/log(2)))
+}
+
+sub to_string { 
+	$_[0]->get_start_ip . '/' . $_[0]->get_length_n
+}
+
 sub get_ip_n {
 	return $_[0]->{ip_n} ;
 }
